@@ -9,7 +9,8 @@ typedef enum {
 	ORBIT_OPTION_NONE,
 	ORBIT_OPTION_STRING,
 	ORBIT_OPTION_INT,
-	ORBIT_OPTION_BOOLEAN
+	ORBIT_OPTION_BOOLEAN,
+	ORBIT_OPTION_KEY_VALUE  /* returns GSList of ORBit_option_key_value */
 } ORBit_option_type;
 
 typedef struct {
@@ -18,6 +19,11 @@ typedef struct {
 	gpointer           arg;
 } ORBit_option;
 
+typedef struct {
+	gchar             *key;
+	gchar             *value;
+} ORBit_OptionKeyValue;
+
 void ORBit_option_parse (int                 *argc,
 			 char               **argv,
 			 const ORBit_option  *option_list);
